==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/GetAssociatedEnclaveCertificateIamRolesRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.CertificateId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetAssociatedEnclaveCertificateIamRolesRequest(
    certificateArn: CertificateId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest = {
    import GetAssociatedEnclaveCertificateIamRolesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .builder()
      .certificateArn(CertificateId.unwrap(certificateArn): java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .wrap(buildAwsValue())
}
object GetAssociatedEnclaveCertificateIamRolesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest =
      zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest(
        certificateArn,
        dryRun.map(value => value)
      )
    def certificateArn: CertificateId
    def dryRun: Optional[Boolean]
    def getCertificateArn: ZIO[Any, Nothing, CertificateId] =
      ZIO.succeed(certificateArn)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ) extends zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly {
    override val certificateArn: CertificateId =
      zio.aws.ec2.model.primitives.CertificateId(impl.certificateArn())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ): zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.126.1-sources.jar: zio/aws/ec2/model/GetAssociatedEnclaveCertificateIamRolesRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ResourceArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetAssociatedEnclaveCertificateIamRolesRequest(
    certificateArn: Option[ResourceArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest = {
    import GetAssociatedEnclaveCertificateIamRolesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .builder()
      .optionallyWith(
        certificateArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.certificateArn)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .wrap(buildAwsValue())
}
object GetAssociatedEnclaveCertificateIamRolesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest =
      zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest(
        certificateArn.map(value => value)
      )
    def certificateArn: Option[ResourceArn]
    def getCertificateArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("certificateArn", certificateArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ) extends zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly {
    override val certificateArn: Option[ResourceArn] = scala
      .Option(impl.certificateArn())
      .map(value => zio.aws.ec2.model.primitives.ResourceArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ): zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    new Wrapper(impl)
}
